# dose_response

[![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/)

Package for bulk processing of dose-response data in tabular format.

See the Medium Article [High-Throughput Dose-Response Data Analysis]() for usage example.

## Version

0.0.1 Initial commit (Current Release)


